#ifndef NT2_INCLUDE_CONSTANTS_NAN_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_NAN_HPP_INCLUDED

#include <nt2/constant/include/constants/nan.hpp>

#endif
